// T3h Package.
package kirk.gui.dialog;

// Import t3h AWT schtuff.
import java.awt.*;

/**
 * An entension of <code>InputDialog</code> that asks the user for a single
 * <code>String</code>.
 * 
 * Use <code>SingleInputRetriever</code> to easily get a value from this object.
 * 
 * @author Berend "Kirk" Wouda
 * @version 1
 * @see kirk.gui.dialog.Retriever
 * @see kirk.gui.dialog.SingleInputRetriever
 */
public class SingleInputDialog extends InputDialog {
	/**
	 * Constructs a new <code>SingleInputDialog<code> with the passed message.
	 * 
	 * @param owner The pwning <code>Frame</code>.
	 * @param retriever The <code>Retriever</code> that will retrieve the value.
	 * @param message The message to be displayed.
	 * @param width The width of this <code>Dialog</code> in pixels.
	 * @param height The height of this <code>Dialog</code> in pixels.
	 * @param columns The width of the input field in characters.
	 */
	public SingleInputDialog(Frame owner, Retriever retriever, String message, int width, int height, int columns) {
		// Call the super constructor.
		super(owner, retriever, width, height);
		
		// Display the message.
		Label messagelabel = new Label(message, Label.CENTER);
		add(messagelabel);
		
		// Add a textfield to this Dialog.
		inputfield = new TextField(columns);
		add(inputfield);
		
		// Make a Panel with an OK and a Cancel button on it.
		Panel buttonpanel = new Panel();
		
		// Add an OK button to this Panel.
		Button okbutton = new Button("OK");
		okbutton.addActionListener(this);
		buttonpanel.add(okbutton);
		
		// Add a Cancel button to this Panel.
		Button cancelbutton = new Button("Cancel");
		cancelbutton.setActionCommand("Cancel");
		cancelbutton.addActionListener(this);
		buttonpanel.add(cancelbutton);
		
		// Add the Panel.
		add(buttonpanel);
	}
	
	
	/**
	 * Returns the value of this <code>InputDialog</code>. In this case, a
	 * <code>String<code>.
	 * 
	 * @return The <code>String<code> the user entered in this
	 * <code>InputDialog</code>.
	 */
	public String getValue() {
		// Return the contents of the TextField.
		return inputfield.getText();
	}

	
	/**
	 * The input field.
	 */
	TextField inputfield;
}