// Thine package.
package kirk.gui.dialog;

// Import Fraim.
import java.awt.Frame;

/**
 * This class retrieves the value inputted in an <code>SingleInputDialog</code>.
 * 
 * You retrieve the <code>String</code> with
 * <code>SingleInputRetriever.getInputValue(Frame owner, String message, int columns)
 * </code>.
 * 
 * @author Berend "Kirk" Wouda
 * @version 1
 * @see kirk.gui.dialog.SingleInputDialog
 */
public class SingleInputRetriever implements Retriever {
	/**
	 * Constructs a new <code>SingleInputRetriever</code>.
	 */
	protected SingleInputRetriever(Frame owner, String message, int width, int height, int columns) {
		// Pop up the Input dialog.
		SingleInputDialog inputdialog = new SingleInputDialog(owner, this, message, width, height, columns);
		
		// Show it.
		inputdialog.show();
	}
	
	
	/**
	 * Sets the input value to the passed value.
	 * Only the <code>InputDialog</code> that was constructed by this class should
	 * use this method.
	 * 
	 * @param inputdialog The value from the <code>InputDialog</code>.
	 */
	public boolean retrieve(InputDialog inputdialog) {
		// Retrieve the String from inputdialog (but cast it first). 
		value = ((SingleInputDialog) inputdialog).getValue();
		
		// Return true, to indicate tht it can close.
		return true;
	}
	
	
	/**
	 * Returns the value retrieved from the <code>SingleInputDialog</code>. 
	 * 
	 * @return The value retrieved from the <code>SingleInputDialog</code>.
	 */
	protected String getValue() {
		// Return the value.
		return value;
	}
	
	
	/**
	 * The value retrieved from the <code>InputDialog</code>.
	 */
	protected String value = null;
	
	
	/**
	 * Creates an <code>SingleInputRetriever</code> and retrieves its value.
	 * 
	 * @param owner The <code>Frame</code> a <code>Dialog</code> has to be popped up
	 * on. 
	 * @param message The message to be displayed on the popup.
	 * @param columns The amount of characters that have to fit in the input field.
	 * @return A <code>String</code> that contains the contents of the input field,
	 * or <code>null</code> if the input was canceled.
	 */
	public static String getValue(Frame owner, String message, int width, int height, int columns) {
		// Construct a new SingleInputRetriever.
		SingleInputRetriever retriever = new SingleInputRetriever(owner, message, width, height, columns);
		
		// Retrieve the value and return it.
		return retriever.getValue();
	}
}