// The package of this class.
package kirk.io.sdl;

/**
 * This class represents an SDL element. It has a name, and a value. What this value
 * actually is, is decided by the subclasses. SDL has 2 types of elements, the normal
 * element, and the data element. These are represented by 2 subclasses.
 * 
 * @author Berend "Kirk" Wouda
 * @version 1
 */
public abstract class SDLElement {
	/**
	 * Constructs a new <code>SDLElement</code> with the given name.
	 * 
	 * @param name The name of the element.
	 */
	public SDLElement(String name) {
		// Set the name.
		setName(name);
	}
	
	
	/**
	 * Returns the name of this element.
	 * 
	 * @return The name of this element.
	 */
	public String getName() {
		// Return the name.
		return name;
	}

	/**
	 * Sets the name of this element to <code>name</code>.
	 * 
	 * @param name The name this element should have.
	 */
	public void setName(String name) {
		// Set the name.
		this.name = name;
	}
	
	
	/**
	 * Convenience method for casting this element to the normal type.
	 * This method is aimed at reducing clutter in code that needs a cast. It also
	 * allows easier chained statements. Casting is something that happens a lot when
	 * retrieving data from the SDL structure, since you need to know/have the
	 * subtype of the element.
	 */
	public SDLNormalElement getAsNormalElement() {
		// Return this element as a normal element.
		return (SDLNormalElement) this;
	}
	
	/**
	 * Convenience method for casting this element to the data type.
	 * This method is aimed at reducing clutter in code that needs a cast. It also
	 * allows easier chained statements. Casting is something that happens a lot when
	 * retrieving data from the SDL structure, since you need to know/have the
	 * subtype of the element.
	 */
	public SDLDataElement getAsDataElement() {
		// Return this element as a data element.
		return (SDLDataElement) this;
	}
	
	
	/**
	 * Returns a string representation of this <code>SDLElement</code> with the given
	 * indentation.
	 * 
	 * @param indent The indentation to be used.
	 * @return A string representation of this <code>SDLElement</code>.
	 */
	public abstract String toString(String indent);
		
	
	/**
	 * The name of this element.
	 */
	protected String name;
}
